@@ -287,7 +287,7 @@ void cmderror(int32 errnumber, ...) {
     printf(badcmdtable[errnumber].msgtext, va_arg(parms, char *));
     break;
   case NOPARM:
-    printf(badcmdtable[errnumber].msgtext);
+    printf("%s", badcmdtable[errnumber].msgtext);
     break;
   default:
     break;
@@ -458,7 +458,8 @@ static detail errortable [] = {
   {NONFATAL, STRING,   0, "OSCLI failed (%s)"},
   {FATAL,    NOPARM,   0, "This build of the interpreter does not support gzipped programs"},
   {WARNING,  NOPARM,   0, "Warning: floating point number format is not known"},
-  {NONFATAL, STRING,   0, "%s"}
+  {NONFATAL, STRING,   0, "%s"},
+  {FATAL,    NOPARM,   0, "SDL Timer initialisation failed"}
 };
 
 /*
