@@ -435,7 +435,10 @@ static boolean waitkey(int wait) {
   SDL_Event ev;
   SDL_TimerID timer_id;
 /* set up timer if wait time not zero */
-  if (wait != 0) timer_id = SDL_AddTimer(wait*10, waitkey_callbackfunc, 0);
+  if (wait != 0) {
+    timer_id = SDL_AddTimer(wait*10, waitkey_callbackfunc, 0);
+    if (timer_id == NULL)  error(ERR_SDL_TIMER);
+  }
   while ( 1 ) {
 /*
  * First check for SDL events
