@@ -1675,7 +1675,7 @@ void exec_oscli(void) {
   fclose(respfile);
   remove(respname);
 /* Save the number of lines stored in the array */
-  if (linecount.typeinfo != 0) store_value(linecount, count, TRUE);
+  if (linecount.typeinfo != 0) store_value(linecount, count);
 }
 
 /*
@@ -2304,7 +2304,9 @@ void exec_sys(void) {
   int32 inregs[MAXSYSPARMS], outregs[MAXSYSPARMS];
   stackitem parmtype;
   basicstring descriptor, tempdesc[MAXSYSPARMS];
+#ifdef TARGET_RISCOS
   lvalue destination;
+#endif
   basicvars.current++;
   expression();		/* Fetch the SWI name or number */
   parmtype = GET_TOPITEM;
@@ -2370,9 +2372,17 @@ void exec_sys(void) {
   }
 /* Make the SWI call */
   emulate_sys(swino, inregs, outregs, &flags);
+
   for (n=0; n<MAXSYSPARMS; n++) {	/* Discard any temporary strings used */
     if (tempdesc[n].stringaddr != NIL) free_string(tempdesc[n]);
   }
+
+/* emulate_sys is only supported on RISCOS systems
+** on all other systems it returns an UNSUPPORTED error
+** so don't bother including the support code if not RISCOS
+*/
+#ifdef TARGET_RISCOS
+
   if (ateol[*basicvars.current]) return;	/* Not returning any parameters so just go home */
   basicvars.current++;
   parmcount = 0;
@@ -2380,7 +2390,7 @@ void exec_sys(void) {
   while (!ateol[*basicvars.current] && *basicvars.current != ';') {
     if (*basicvars.current != ',') {	/* Want this return value */
       get_lvalue(&destination);
-      store_value(destination, outregs[parmcount], STRINGOK);
+      store_stg_value(destination, outregs[parmcount]);
     }
     parmcount++;
     if (parmcount>=MAXSYSPARMS) error(ERR_SYSCOUNT);
@@ -2393,9 +2403,10 @@ void exec_sys(void) {
   if (*basicvars.current == ';') {	/* Want flags as well */
     basicvars.current++;	/* Skip ';' token */
     get_lvalue(&destination);
-    store_value(destination, flags, NOSTRING);
+    store_value(destination, flags);
   }
   check_ateol();
+#endif
 }
 
 /*
