@@ -156,12 +156,13 @@ typedef double float64;			/* Type for 64-bit floating point variables in Basic *
 ** The ALIGN macro is used to control the sizes of blocks of
 ** memory allocated from the heap. They are always a multiple
 ** of ALIGN bytes.
+**
+** Note the use of 'char *': this is to make it automatically
+** align things on a 32-bit or 64-bit boundary according to
+** the size of a pointer (32 or 64 bits).
 */
-#ifdef TARGET_HPUX
-#define ALIGN(x) ((x+sizeof(double)-1) & -(int)sizeof(double))
-#else
-#define ALIGN(x) ((x+sizeof(int32)-1) & -(int)sizeof(int32))
-#endif
+
+#define ALIGN(x) ((x+sizeof(char *)-1) & -(int)sizeof(char *))
 
 /*
 ** Name of editor invoked by Basic 'EDIT' command
